@@ -31,7 +31,6 @@
 #include "ephy-settings.h"
 #include "ephy-smaps.h"
 #include "ephy-snapshot-service.h"
-#include "ephy-vcs-version.h"
 #include "ephy-web-app-utils.h"
 
 #include <gio/gio.h>
@@ -96,114 +95,6 @@ ephy_about_handler_finish_request (WebKitURISchemeRequest *request,
   g_object_unref (stream);
 }
 
-typedef struct {
-  EphyAboutHandler *handler;
-  WebKitURISchemeRequest *request;
-} EphyAboutRequest;
-
-static EphyAboutRequest *
-ephy_about_request_new (EphyAboutHandler       *handler,
-                        WebKitURISchemeRequest *request)
-{
-  EphyAboutRequest *about_request;
-
-  about_request = g_slice_new (EphyAboutRequest);
-  about_request->handler = g_object_ref (handler);
-  about_request->request = g_object_ref (request);
-
-  return about_request;
-}
-
-static void
-ephy_about_request_free (EphyAboutRequest *about_request)
-{
-  g_object_unref (about_request->handler);
-  g_object_unref (about_request->request);
-
-  g_slice_free (EphyAboutRequest, about_request);
-}
-
-static void
-get_plugins_cb (WebKitWebContext *web_context,
-                GAsyncResult     *result,
-                EphyAboutRequest *about_request)
-{
-  GString *data_str;
-  gsize data_length;
-  GList *plugin_list, *p;
-  gboolean enabled;
-
-  enabled = g_settings_get_boolean (EPHY_SETTINGS_WEB, EPHY_PREFS_WEB_ENABLE_PLUGINS);
-
-  data_str = g_string_new ("<html>");
-  g_string_append_printf (data_str, "<head><title>%s</title>"
-                          "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" />"
-                          "<link href=\""EPHY_PAGE_TEMPLATE_ABOUT_CSS "\" rel=\"stylesheet\" type=\"text/css\">"
-                          "</head><body>",
-                          _("Installed plugins"));
-  g_string_append_printf (data_str, "<h1>%s</h1>", _("Plugins"));
-
-  if (!enabled)
-    g_string_append_printf (data_str, "<p><b>%s</b></p>", _("Plugins are disabled in the preferences"));
-
-  plugin_list = webkit_web_context_get_plugins_finish (web_context, result, NULL);
-  for (p = plugin_list; p; p = p->next) {
-    WebKitPlugin *plugin = WEBKIT_PLUGIN (p->data);
-    GList *m, *mime_types;
-
-    /* TODO: Enable/disable plugins in WebKit2 */
-    g_string_append_printf (data_str, "<h2>%s</h2>%s<br>%s: <b>%s</b>"  \
-                            "<table id=\"plugin-table\">"               \
-                            "  <thead><tr><th>%s</th><th>%s</th><th>%s</th></tr></thead><tbody>",
-                            webkit_plugin_get_name (plugin),
-                            webkit_plugin_get_description (plugin),
-                            _("Enabled"), /*webkit_plugin_get_enabled (plugin) && */ enabled ? _("Yes") : _("No"),
-                            _("MIME type"), _("Description"), _("Suffixes"));
-
-    mime_types = webkit_plugin_get_mime_info_list (plugin);
-
-    for (m = mime_types; m; m = m->next) {
-      WebKitMimeInfo *mime_info = (WebKitMimeInfo *)m->data;
-      const gchar * const *extensions;
-      guint i;
-
-      g_string_append_printf (data_str, "<tr><td>%s</td><td>%s</td><td>",
-                              webkit_mime_info_get_mime_type (mime_info),
-                              webkit_mime_info_get_description (mime_info));
-
-      extensions = webkit_mime_info_get_extensions (mime_info);
-      for (i = 0; extensions && extensions[i] != NULL; i++)
-        g_string_append_printf (data_str, "%s%c", extensions[i],
-                                extensions[i + 1] ? ',' : ' ');
-
-      g_string_append (data_str, "</td></tr>");
-    }
-
-    g_string_append (data_str, "</tbody></table>");
-  }
-  g_string_append (data_str, "</body></html>");
-
-  g_list_free_full (plugin_list, g_object_unref);
-
-  data_length = data_str->len;
-  ephy_about_handler_finish_request (about_request->request, g_string_free (data_str, FALSE), data_length);
-  ephy_about_request_free (about_request);
-}
-
-static gboolean
-ephy_about_handler_handle_plugins (EphyAboutHandler       *handler,
-                                   WebKitURISchemeRequest *request)
-{
-  EphyEmbedShell *shell = ephy_embed_shell_get_default ();
-
-  webkit_web_context_get_plugins (ephy_embed_shell_get_web_context (shell),
-                                  NULL,
-                                  (GAsyncReadyCallback)get_plugins_cb,
-                                  ephy_about_request_new (handler, request));
-
-  return TRUE;
-}
-
 static void
 handle_memory_finished_cb (EphyAboutHandler       *handler,
                            GAsyncResult           *result,
@@ -220,12 +111,15 @@ handle_memory_finished_cb (EphyAboutHandler       *handler,
     g_string_append_printf (data_str, "<head><title>%s</title>"
                             "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" />"
                             "<link href=\""EPHY_PAGE_TEMPLATE_ABOUT_CSS "\" rel=\"stylesheet\" type=\"text/css\">"
-                            "</head><body>",
+                            "</head><body>"
+                            "<div id='memory'>",
                             _("Memory usage"));
 
     g_string_append_printf (data_str, "<h1>%s</h1>", _("Memory usage"));
     g_string_append (data_str, memory);
     g_free (memory);
+
+    g_string_append (data_str, "</div>");
   }
 
   g_string_append (data_str, "</html>");
@@ -271,32 +165,37 @@ ephy_about_handler_handle_about (EphyAboutHandler       *handler,
   char *version;
   GtkIconInfo *icon_info;
 
-  version = g_strdup_printf (_("Version %s"), VCSVERSION);
+  version = g_strdup_printf (_("Version %s"), VERSION);
 
   icon_info = gtk_icon_theme_lookup_icon (gtk_icon_theme_get_default (),
-                                          "org.gnome.Epiphany",
-                                          512,
-                                          GTK_ICON_LOOKUP_GENERIC_FALLBACK);
+                                          APPLICATION_ID,
+                                          256,
+                                          GTK_ICON_LOOKUP_FORCE_SVG);
 
   data = g_strdup_printf ("<html><head><title>%s</title>"
                           "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" />"
                           "<link href=\""EPHY_PAGE_TEMPLATE_ABOUT_CSS "\" rel=\"stylesheet\" type=\"text/css\">"
                           "</head><body>"
+                          "<div id=\"about-app\">"
                           "<div class=\"dialog\">"
-                          "<img src=\"file://%s\"/>"
+                          "<img id=\"about-icon\" src=\"file://%s\"/>"
                           "<h1 id=\"about-title\">%s</h1>"
                           "<h2 id=\"about-subtitle\">%s</h2>"
                           "<p id=\"about-tagline\">%s</p>"
                           "<table class=\"properties\">"
                           "<tr><td class=\"prop-label\">%s</td><td class=\"prop-value\">%d.%d.%d</td></tr>"
                           "</table>"
-                          "</div></body></html>",
+                          "</div></div></body></html>",
                           _("About Web"),
                           icon_info ? gtk_icon_info_get_filename (icon_info) : "",
+#if !TECH_PREVIEW
                           _("Web"),
+#else
+                          _("Epiphany Technology Preview"),
+#endif
                           version,
                           _("A simple, clean, beautiful view of the web"),
-                          "WebKit", webkit_get_major_version (), webkit_get_minor_version (), webkit_get_micro_version ());
+                          "WebKitGTK", webkit_get_major_version (), webkit_get_minor_version (), webkit_get_micro_version ());
   g_free (version);
   if (icon_info)
     g_object_unref (icon_info);
@@ -341,41 +240,68 @@ handle_applications_finished_cb (EphyAboutHandler       *handler,
   GList *applications, *p;
 
   data_str = g_string_new (NULL);
-  g_string_append_printf (data_str, "<html><head><title>%s</title>"
-                          "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" />"
-                          "<link href=\""EPHY_PAGE_TEMPLATE_ABOUT_CSS "\" rel=\"stylesheet\" type=\"text/css\">"
-                          "<script>"
-                          "  function deleteWebApp(appID) {"
-                          "    window.webkit.messageHandlers.aboutApps.postMessage(appID);"
-                          "    var row = document.getElementById(appID);"
-                          "    row.parentNode.removeChild(row);"
-                          "  }"
-                          "</script>"
-                          "</head><body class=\"applications-body\"><h1>%s</h1>"
-                          "<p>%s</p>",
-                          _("Applications"),
-                          _("Applications"),
-                          _("List of installed web applications"));
-
-  g_string_append (data_str, "<table>");
-
   applications = g_task_propagate_pointer (G_TASK (result), NULL);
-  for (p = applications; p; p = p->next) {
-    EphyWebApplication *app = (EphyWebApplication *)p->data;
 
+  if (g_list_length (applications) > 0) {
+    g_string_append_printf (data_str, "<html><head><title>%s</title>"
+                            "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" />"
+                            "<link href=\""EPHY_PAGE_TEMPLATE_ABOUT_CSS "\" rel=\"stylesheet\" type=\"text/css\">"
+                            "<script>"
+                            "  function deleteWebApp(appID) {"
+                            "    window.webkit.messageHandlers.aboutApps.postMessage(appID);"
+                            "    var row = document.getElementById(appID);"
+                            "    row.parentNode.removeChild(row);"
+                            "  }"
+                            "</script>"
+                            "</head><div id=\"applications\"><body class=\"applications-body\"><h1>%s</h1>"
+                            "<p>%s</p>",
+                            _("Applications"),
+                            _("Applications"),
+                            _("List of installed web applications"));
+
+    g_string_append (data_str, "<table>");
+
+    for (p = applications; p; p = p->next) {
+      EphyWebApplication *app = (EphyWebApplication *)p->data;
+
+      g_string_append_printf (data_str,
+                              "<tbody><tr id =\"%s\">"
+                              "<td class=\"icon\"><img width=64 height=64 src=\"file://%s\"></img></td>"
+                              "<td class=\"data\"><div class=\"appname\">%s</div><div class=\"appurl\">%s</div></td>"
+                              "<td class=\"input\"><input type=\"button\" value=\"%s\" onclick=\"deleteWebApp('%s');\"></td>"
+                              "<td class=\"date\">%s <br /> %s</td></tr></tbody>",
+                              app->id, app->icon_url, app->name, app->url, _("Delete"), app->id,
+                              /* Note for translators: this refers to the installation date. */
+                              _("Installed on:"), app->install_date);
+    }
+
+    g_string_append (data_str, "</table></div></body></html>");
+  } else {
+    g_autoptr (GtkIconInfo) icon_info = NULL;
+    g_autofree gchar *icon = g_strconcat ("application-x-addon-symbolic", NULL);
+
+    g_string_append_printf (data_str, "<html><head><title>%s</title>"
+                            "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" />"
+                            "<link href=\""EPHY_PAGE_TEMPLATE_ABOUT_CSS "\" rel=\"stylesheet\" type=\"text/css\">"
+                            "</head><body class=\"applications-body\">",
+                            _("Applications"));
+
+    icon_info = gtk_icon_theme_lookup_icon (gtk_icon_theme_get_default (),
+                                            icon,
+                                            128,
+                                            0);
     g_string_append_printf (data_str,
-                            "<tbody><tr id =\"%s\">"
-                            "<td class=\"icon\"><img width=64 height=64 src=\"file://%s\"></img></td>"
-                            "<td class=\"data\"><div class=\"appname\">%s</div><div class=\"appurl\">%s</div></td>"
-                            "<td class=\"input\"><input type=\"button\" value=\"%s\" onclick=\"deleteWebApp('%s');\"></td>"
-                            "<td class=\"date\">%s <br /> %s</td></tr></tbody>",
-                            app->name, app->icon_url, app->name, app->url, _("Delete"), app->name,
-                            /* Note for translators: this refers to the installation date. */
-                            _("Installed on:"), app->install_date);
+                            "  <div id=\"overview\" class=\"overview-empty\">\n"
+                            "    <img src=\"file://%s\"/>\n"
+                            "    <div><h1>%s</h1></div>\n"
+                            "    <div><p>%s</p></div>\n"
+                            "  </div>\n"
+                            "</body></html>\n",
+                            icon_info ? gtk_icon_info_get_filename (icon_info) : "",
+                            /* Displayed when opening applications without any installed web apps. */
+                            _("Applications"), _("You can add your favorite website by clicking <b>Install Site as Web Application…</b> within the page menu."));
   }
 
-  g_string_append (data_str, "</table></body></html>");
-
   ephy_web_application_free_application_list (applications);
 
   data_length = data_str->len;
@@ -421,6 +347,7 @@ history_service_query_urls_cb (EphyHistoryService     *history,
   gsize data_length;
   char *lang;
   GList *l;
+  guint list_length;
 
   snapshot_service = ephy_snapshot_service_get_default ();
   shell = ephy_embed_shell_get_default ();
@@ -437,22 +364,7 @@ history_service_query_urls_cb (EphyHistoryService     *history,
                           "  <meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\" />\n"
                           "  <meta name=\"viewport\" content=\"width=device-width\">"
                           "  <link href=\""EPHY_PAGE_TEMPLATE_ABOUT_CSS "\" rel=\"stylesheet\" type=\"text/css\">\n"
-                          "  <script>\n"
-                          "    document.onkeypress = function listenKeypress(event) {\n"
-                          "      // Remove from overview when Del is pressed\n"
-                          "      if (event.which == 127) {\n"
-                          "        var focused = document.activeElement;\n"
-                          "        if (focused.className == \"overview-item\") {\n"
-                          "          removeFromOverview(focused, event);\n"
-                          "        }\n"
-                          "      }\n"
-                          "    }\n"
-                          "    function removeFromOverview(elem, event) {\n"
-                          "      event.preventDefault();\n"
-                          "      elem.className +=\" overview-removed \";\n"
-                          "      window.webkit.messageHandlers.overview.postMessage(elem.href);\n"
-                          "    }\n"
-                          "  </script>\n"
+                          "  <script> </script>\n"
                           "</head>\n"
                           "<body>\n",
                           lang, lang,
@@ -460,15 +372,18 @@ history_service_query_urls_cb (EphyHistoryService     *history,
                           _(OVERVIEW_PAGE_TITLE));
   g_free (lang);
 
-  if (g_list_length (urls) == 0 || !success) {
+  list_length = g_list_length (urls);
+
+  if (list_length == 0 || !success) {
     GtkIconInfo *icon_info;
+    g_autofree gchar *icon = g_strconcat (APPLICATION_ID, "-symbolic", NULL);
 
     icon_info = gtk_icon_theme_lookup_icon (gtk_icon_theme_get_default (),
-                                            "org.gnome.Epiphany-symbolic",
+                                            icon,
                                             128,
                                             0);
     g_string_append_printf (data_str,
-                            "  <div class=\"overview-empty\">\n"
+                            "  <div id=\"overview\" class=\"overview-empty\">\n"
                             "    <img src=\"file://%s\"/>\n"
                             "    <div><h1>%s</h1></div>\n"
                             "    <div><p>%s</p></div>\n"
@@ -485,33 +400,38 @@ history_service_query_urls_cb (EphyHistoryService     *history,
   g_string_append (data_str,
                    "<div id=\"overview\">\n");
 
+  g_string_append (data_str,
+                   "<div id=\"most-visited-grid\">\n");
+
   for (l = urls; l; l = g_list_next (l)) {
     EphyHistoryURL *url = (EphyHistoryURL *)l->data;
     const char *snapshot;
-    char *thumbnail_style = NULL;
+    g_autofree char *thumbnail_style = NULL;
+    g_autofree char *markup = NULL;
 
     snapshot = ephy_snapshot_service_lookup_cached_snapshot_path (snapshot_service, url->url);
     if (snapshot)
-      thumbnail_style = g_strdup_printf (" style=\"background: url(file://%s) no-repeat;\"", snapshot);
+      thumbnail_style = g_strdup_printf (" style=\"background: url(file://%s) no-repeat; background-size: 100%%;\"", snapshot);
     else
       ephy_embed_shell_schedule_thumbnail_update (shell, url);
 
+    markup = g_markup_escape_text (url->title, -1);
     g_string_append_printf (data_str,
                             "<a class=\"overview-item\" title=\"%s\" href=\"%s\">"
-                            "  <div class=\"overview-close-button\" onclick=\"removeFromOverview(this.parentNode, event)\" title=\"%s\">&#10006;</div>"
+                            "  <div class=\"overview-close-button\" title=\"%s\"></div>"
                             "  <span class=\"overview-thumbnail\"%s></span>"
                             "  <span class=\"overview-title\">%s</span>"
                             "</a>",
-                            g_markup_escape_text (url->title, -1), url->url, _("Remove from overview"),
+                            markup, url->url, _("Remove from overview"),
                             thumbnail_style ? thumbnail_style : "", url->title);
-    g_free (thumbnail_style);
   }
 
   data_str = g_string_append (data_str,
+                              "  </div>\n"
                               "  </div>\n"
                               "</body></html>\n");
 
- out:
+out:
   data_length = data_str->len;
   ephy_about_handler_finish_request (request, g_string_free (data_str, FALSE), data_length);
   g_object_unref (request);
@@ -565,13 +485,11 @@ ephy_about_handler_handle_incognito (EphyAboutHandler       *handler,
                           "<link href=\""EPHY_PAGE_TEMPLATE_ABOUT_CSS "\" rel=\"stylesheet\" type=\"text/css\">\n"
                           "</head>\n"
                           "<body class=\"incognito-body\">\n"
-                          "  <div id=\"mainblock\">\n"
-                          "    <div style=\"background: transparent url(ephy-resource:///org/gnome/epiphany/incognito.png) no-repeat 10px center;\">\n" \
-                          "      <h1>%s</h1>\n"
-                          "      <p>%s</p>\n"
-                          "      <p><strong>%s</strong> %s</p>\n"
-                          "    </div>\n"
-                          "  </div>\n"
+                          "  <img class=\"incognito-body-image\" src=\"ephy-resource:///org/gnome/epiphany/private-mode.svg\">\n" \
+                          "  <br/>\n"
+                          "  <h1>%s</h1>\n"
+                          "  <p>%s</p>\n"
+                          "  <p><strong>%s</strong> %s</p>\n"
                           "</body>\n"
                           "</div>\n"
                           "</html>\n",
@@ -616,9 +534,7 @@ ephy_about_handler_handle_request (EphyAboutHandler       *handler,
 
   path = webkit_uri_scheme_request_get_path (request);
 
-  if (!g_strcmp0 (path, "plugins"))
-    handled = ephy_about_handler_handle_plugins (handler, request);
-  else if (!g_strcmp0 (path, "memory"))
+  if (!g_strcmp0 (path, "memory"))
     handled = ephy_about_handler_handle_memory (handler, request);
   else if (!g_strcmp0 (path, "epiphany"))
     handled = ephy_about_handler_handle_epiphany (handler, request);
